@@ -21,7 +21,11 @@ def main():
     for opt, arg in opts:
         if opt in ('-h', '--help'):
             print(
-                'prog -s i am a server, connect to a client(no new session), . -t token, this is optional for client, must be set for server. -b bridge(default is test.mosquitto.org). -p port(default is 1883). -f topic prefix(default \'\') ')
+                'prog -s -t token -b bridge_server_name -p bridge_server_port -f topic_prefix\n'
+                '-s i am a server, connect to a client(no new session),\n'
+                ' -t token, this is optional for client, must be set for server.\n'
+                ' -b bridge(default is test.mosquitto.org). \n'
+                '-p port(default is 1883). -f topic prefix(default \'\') \n')
             sys.exit()
         elif opt in ("-s", "--server"):
             join_a_client = True
@@ -46,11 +50,11 @@ def main():
         client.set_token(token)
         client.set_bridge(server, port, prefix)
         if len(prefix) > 0:
-            print('client started, use: term_from_nat -s -t  ' + token + ' -b ' + server + ' -p ' + str(
-                port) + ' -f ' + prefix + '\n to start the server')
+            print('client started, USE: \nterm_from_nat -s -t  ' + token + ' -b ' + server + ' -p ' + str(
+                port) + ' -f ' + prefix + '\n TO START THE SERVER from another computer')
         else:
-            print('client started, use: term_from_nat -s -t  ' + token + ' -b ' + server + ' -p ' + str(
-                port) + '\n to start the server')
+            print('client started, USE: \nterm_from_nat -s -t  ' + token + ' -b ' + server + ' -p ' + str(
+                port) + '\n TO START THE SERVER from another computer')
         client.start_server()
 
 
